@@ -14,6 +14,7 @@ describe 'neutron::agents::ml2::sriov' do
       :exclude_devices            => [],
       :polling_interval           => 2,
       :supported_pci_vendor_devs  => [],
+      :purge_config               => false,
     }
   end
 
@@ -34,6 +35,12 @@ describe 'neutron::agents::ml2::sriov' do
 
     it { is_expected.to contain_class('neutron::params') }
 
+    it 'passes purge to resource' do
+      is_expected.to contain_resources('neutron_sriov_agent_config').with({
+        :purge => false
+      })
+    end
+
     it 'configures /etc/neutron/plugins/ml2/sriov_agent.ini' do
       is_expected.to contain_neutron_sriov_agent_config('sriov_nic/polling_interval').with_value(p[:polling_interval])
       is_expected.to contain_neutron_sriov_agent_config('sriov_nic/exclude_devices').with_value(p[:exclude_devices].join(','))
@@ -49,7 +56,8 @@ describe 'neutron::agents::ml2::sriov' do
         :ensure => p[:package_ensure],
         :tag    => ['openstack', 'neutron-package'],
       )
-      is_expected.to contain_package('neutron-sriov-nic-agent').with_before(/Neutron_sriov_agent_config\[.+\]/)
+      is_expected.to contain_package('neutron-sriov-nic-agent').that_requires('Anchor[neutron::install::begin]')
+      is_expected.to contain_package('neutron-sriov-nic-agent').that_notifies('Anchor[neutron::install::end]')
     end
 
     it 'configures neutron sriov agent service' do
@@ -57,10 +65,10 @@ describe 'neutron::agents::ml2::sriov' do
         :name    => platform_params[:sriov_nic_agent_service],
         :enable  => true,
         :ensure  => 'running',
-        :require => 'Class[Neutron]',
         :tag     => 'neutron-service',
       )
-      is_expected.to contain_service('neutron-sriov-nic-agent-service').that_subscribes_to( [ 'Package[neutron]', 'Package[neutron-sriov-nic-agent]' ] )
+      is_expected.to contain_service('neutron-sriov-nic-agent-service').that_subscribes_to('Anchor[neutron::service::begin]')
+      is_expected.to contain_service('neutron-sriov-nic-agent-service').that_notifies('Anchor[neutron::service::end]')
     end
 
     context 'with manage_service as false' do
