@@ -93,8 +93,10 @@ describe 'neutron::plugins::ml2' do
         is_expected.to contain_package('neutron-plugin-ml2').with(
           :name   => platform_params[:ml2_server_package],
           :ensure => p[:package_ensure],
-          :tag    => 'openstack'
+          :tag    => ['neutron-package', 'openstack'],
         )
+        is_expected.to contain_package('neutron-plugin-ml2').that_requires('Anchor[neutron::install::begin]')
+        is_expected.to contain_package('neutron-plugin-ml2').that_notifies('Anchor[neutron::install::end]')
       end
     end
 
@@ -207,6 +209,21 @@ describe 'neutron::plugins::ml2' do
       it_raises  'a Puppet::Error', /vni ranges are invalid./
     end
 
+    context 'when using geneve driver' do
+      before :each do
+        params.merge!(:type_drivers    => ['local', 'flat', 'vlan', 'gre', 'vxlan', 'geneve'],
+                      :vni_ranges      => ['40:300','500:1000'],
+                      :max_header_size => 50
+        )
+      end
+
+      it 'configures geneve with valid values' do
+        is_expected.to contain_neutron_plugin_ml2('ml2/type_drivers').with_value(p[:type_drivers].join(','))
+        is_expected.to contain_neutron_plugin_ml2('ml2_type_geneve/vni_ranges').with_value([p[:vni_ranges].join(',')])
+        is_expected.to contain_neutron_plugin_ml2('ml2_type_geneve/max_header_size').with_value(p[:max_header_size])
+      end
+    end
+
     context 'with path_mtu set' do
       before :each do
         params.merge!(:path_mtu => '9000')
@@ -236,7 +253,7 @@ describe 'neutron::plugins::ml2' do
           is_expected.to contain_package('neutron-plugin-ml2').with(
             :name   => platform_params[:ml2_server_package],
             :ensure => params[:package_ensure],
-            :tag    => 'openstack'
+            :tag    => ['neutron-package', 'openstack'],
           )
         end
       end
@@ -265,8 +282,9 @@ describe 'neutron::plugins::ml2' do
           :path    => '/etc/default/neutron-server',
           :match   => '^NEUTRON_PLUGIN_CONFIG=(.*)$',
           :line    => 'NEUTRON_PLUGIN_CONFIG=/etc/neutron/plugin.ini',
-          :require => ['File[/etc/default/neutron-server]','File[/etc/neutron/plugin.ini]']
         )
+        is_expected.to contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').that_requires('Anchor[neutron::config::begin]')
+        is_expected.to contain_file_line('/etc/default/neutron-server:NEUTRON_PLUGIN_CONFIG').that_notifies('Anchor[neutron::config::end]')
       end
     end
   end
