@@ -7,12 +7,12 @@ describe 'neutron::server' do
   end
 
   let :params do
-    { :password           => 'passw0rd',
-      :username           => 'neutron',
-      :keystone_auth_type => 'password',
-      :project_domain_id  => 'Default',
-      :project_name       => 'services',
-      :user_domain_id     => 'Default'}
+    { :password            => 'passw0rd',
+      :username            => 'neutron',
+      :keystone_auth_type  => 'password',
+      :project_domain_name => 'Default',
+      :project_name        => 'services',
+      :user_domain_name    => 'Default'}
   end
 
   let :default_params do
@@ -56,13 +56,16 @@ describe 'neutron::server' do
       is_expected.to contain_neutron_config('keystone_authtoken/password').with_secret( true )
       is_expected.to contain_neutron_config('keystone_authtoken/auth_uri').with_value("http://localhost:5000/");
       is_expected.to contain_neutron_config('keystone_authtoken/auth_url').with_value("http://localhost:35357/");
-      is_expected.to contain_neutron_config('keystone_authtoken/project_domain_id').with_value(p[:project_domain_id]);
+      is_expected.to contain_neutron_config('keystone_authtoken/project_domain_name').with_value(p[:project_domain_name]);
+      is_expected.to contain_neutron_config('keystone_authtoken/project_domain_id').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_config('keystone_authtoken/project_name').with_value(p[:project_name]);
-      is_expected.to contain_neutron_config('keystone_authtoken/user_domain_id').with_value(p[:user_domain_id]);
+      is_expected.to contain_neutron_config('keystone_authtoken/user_domain_name').with_value(p[:user_domain_name]);
+      is_expected.to contain_neutron_config('keystone_authtoken/user_domain_id').with_value('<SERVICE DEFAULT>');
       is_expected.to contain_neutron_config('keystone_authtoken/admin_tenant_name').with_ensure('absent');
       is_expected.to contain_neutron_config('keystone_authtoken/admin_user').with_ensure('absent');
       is_expected.to contain_neutron_config('keystone_authtoken/admin_password').with_ensure('absent');
       is_expected.to contain_neutron_config('keystone_authtoken/identity_uri').with_ensure('absent');
+      is_expected.to contain_neutron_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>');
     end
 
     it 'installs neutron server package' do
@@ -72,11 +75,11 @@ describe 'neutron::server' do
           :ensure => p[:package_ensure],
           :tag    => ['openstack', 'neutron-package'],
         )
-        is_expected.to contain_package('neutron-server').with_before(/Neutron_api_config\[.+\]/)
-        is_expected.to contain_package('neutron-server').with_before(/Neutron_config\[.+\]/)
-        is_expected.to contain_package('neutron-server').with_before(/Service\[neutron-server\]/)
+        is_expected.to contain_package('neutron-server').that_requires('Anchor[neutron::install::begin]')
+        is_expected.to contain_package('neutron-server').that_notifies('Anchor[neutron::install::end]')
       else
-        is_expected.to contain_package('neutron').with_before(/Neutron_api_config\[.+\]/)
+        is_expected.to contain_package('neutron').that_requires('Anchor[neutron::install::begin]')
+        is_expected.to contain_package('neutron').that_notifies('Anchor[neutron::install::end]')
       end
     end
 
@@ -85,9 +88,10 @@ describe 'neutron::server' do
         :name    => platform_params[:server_service],
         :enable  => true,
         :ensure  => 'running',
-        :require => 'Class[Neutron]',
         :tag     => ['neutron-service', 'neutron-db-sync-service'],
       )
+      is_expected.to contain_service('neutron-server').that_subscribes_to('Anchor[neutron::service::begin]')
+      is_expected.to contain_service('neutron-server').that_notifies('Anchor[neutron::service::end]')
       is_expected.not_to contain_class('neutron::db::sync')
       is_expected.to contain_service('neutron-server').with_name('neutron-server')
       is_expected.to contain_neutron_config('DEFAULT/api_workers').with_value(facts[:processorcount])
@@ -185,6 +189,12 @@ describe 'neutron::server' do
       end
     end
 
+    context 'with allow_automatic_dhcp_failover in neutron.conf' do
+      it 'should configure allow_automatic_dhcp_failover' do
+        is_expected.to contain_neutron_config('DEFAULT/allow_automatic_dhcp_failover').with_value('<SERVICE DEFAULT>')
+      end
+    end
+
     context 'with qos_notification_drivers parameter' do
       before :each do
         params.merge!(:qos_notification_drivers => 'message_queue')
@@ -194,6 +204,12 @@ describe 'neutron::server' do
       end
     end
 
+    context 'with network_auto_schedule in neutron.conf' do
+      it 'should configure network_auto_schedule' do
+        is_expected.to contain_neutron_config('DEFAULT/network_auto_schedule').with_value('<SERVICE DEFAULT>')
+      end
+    end
+
     context 'with deprecated auth_plugin parameter' do
       before :each do
         params.merge!(:auth_plugin => 'v2password')
@@ -326,20 +342,37 @@ describe 'neutron::server' do
     end
     before do
       params.merge!({
-        :auth_uri           => 'https://foo.bar:5000/',
-        :auth_url           => 'https://foo.bar:35357/v3',
-        :keystone_auth_type => 'v3password',
-        :project_domain_id  => 'non_default',
-        :project_name       => 'new_services',
-        :user_domain_id     => 'non_default'
+        :auth_uri            => 'https://foo.bar:5000/',
+        :auth_url            => 'https://foo.bar:35357/v3',
+        :keystone_auth_type  => 'v3password',
+        :project_domain_name => 'non_default',
+        :project_name        => 'new_services',
+        :user_domain_name    => 'non_default'
       })
     end
     it 'configures keystone authentication params' do
       is_expected.to contain_neutron_config('keystone_authtoken/auth_uri').with_value("https://foo.bar:5000/");
       is_expected.to contain_neutron_config('keystone_authtoken/auth_url').with_value("https://foo.bar:35357/v3");
-      is_expected.to contain_neutron_config('keystone_authtoken/project_domain_id').with_value("non_default");
+      is_expected.to contain_neutron_config('keystone_authtoken/project_domain_name').with_value("non_default");
       is_expected.to contain_neutron_config('keystone_authtoken/project_name').with_value("new_services");
-      is_expected.to contain_neutron_config('keystone_authtoken/user_domain_id').with_value("non_default");
+      is_expected.to contain_neutron_config('keystone_authtoken/user_domain_name').with_value("non_default");
+    end
+  end
+
+  describe "with keystoneauth memcache servers" do
+    let :facts do
+      @default_facts.merge(test_facts.merge({
+         :osfamily => 'RedHat',
+         :operatingsystemrelease => '7'
+      }))
+    end
+    before do
+      params.merge!({
+        :memcached_servers => '1.1.1.1:11211'
+      })
+    end
+    it 'configures keystone authentication memached servers' do
+        is_expected.to contain_neutron_config('keystone_authtoken/memcached_servers').with_value('1.1.1.1:11211');
     end
   end
 
